==> MedPy-0.4.0.tar.gz: MedPy-0.4.0/README.md <==
[![PyPI version fury.io](https://badge.fury.io/py/MedPy.svg)](https://pypi.python.org/pypi/MedPy/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/MedPy.svg)](https://pypi.python.org/pypi/MedPy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Downloads](https://pepy.tech/badge/medpy/month)](https://pepy.tech/project/medpy)
![travis auto-build](https://travis-ci.org/loli/medpy.svg?branch=master)
[![DOI](https://zenodo.org/badge/4295983.svg)](https://zenodo.org/badge/latestdoi/4295983)

[GitHub](https://github.com/loli/medpy/) | [Documentation](http://loli.github.io/medpy/) | [Tutorials](http://loli.github.io/medpy/) | [Issue tracker](https://github.com/loli/medpy/issues) | [Contact](oskar.maier@gmail.com)

# medpy - Medical Image Processing in Python

MedPy is an image processing library and collection of scripts targeted towards medical (i.e. high dimensional) image processing.

## Stable releases

- Download (stable release): https://pypi.python.org/pypi/medpy
- HTML documentation and installation instruction (stable release): http://loli.github.io/medpy/

## Development version

- Download (development version): https://github.com/loli/medpy
- HTML documentation and installation instruction (development version): create this from doc/ folder following instructions in contained README file

## Python 2 version

Python 2 is no longer supported. But you can still use the older releases `<=0.3.0`.

## Other links

- Issue tracker: https://github.com/loli/medpy/issues

==> MedPy2-0.0.2.tar.gz: MedPy2-0.0.2/README.md <==
[![PyPI version fury.io](https://badge.fury.io/py/MedPy.svg)](https://pypi.python.org/pypi/MedPy/)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/medpy/README.html)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/MedPy.svg)](https://pypi.python.org/pypi/MedPy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Downloads](https://pepy.tech/badge/medpy/month)](https://pepy.tech/project/medpy)
![travis auto-build](https://travis-ci.org/loli/medpy.svg?branch=master)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2565940.svg)](https://doi.org/10.5281/zenodo.2565940)


[GitHub](https://github.com/loli/medpy/) | [Documentation](http://loli.github.io/medpy/) | [Tutorials](http://loli.github.io/medpy/) | [Issue tracker](https://github.com/loli/medpy/issues) | [Contact](oskar.maier@gmail.com)

# medpy - Medical Image Processing in Python

MedPy is an image processing library and collection of scripts targeted towards medical (i.e. high dimensional) image processing.

## Stable releases

- Download (stable release): https://pypi.python.org/pypi/medpy
- HTML documentation and installation instruction (stable release): http://loli.github.io/medpy/
- Download from [Bioconda](https://bioconda.github.io/): https://bioconda.github.io/recipes/medpy/README.html#package-medpy (thanks to [PertuyF](https://github.com/PertuyF), see [#96](https://github.com/loli/medpy/issues/96))

## Development version

- Download (development version): https://github.com/loli/medpy
- HTML documentation and installation instruction (development version): create this from doc/ folder following instructions in contained README file

## Python 2 version

Python 2 is no longer supported. But you can still use the older releases `<=0.3.0`.

## Other links

- Issue tracker: https://github.com/loli/medpy/issues
